Simulation
Recipe Describe the science
Context Determine the Hardware
Domain decomposition Map recipe to hardware
An overview of Arbor at the highest level. The layout reflects a division that is core to Arbor: the science is described entirely separate from the execution of the simulation. The Recipe describes the network by declaring its constituent cells and their connections in addition to the stimuli and data extraction. Execution is determined by mapping out the available hardware in a context as processes (via MPI) plus the threads and GPUs associated with each process. Finally, a domain decomposition maps the network onto said resources taking into account the capabilities of each cell type.